@@ -60,6 +60,9 @@ void AlarmWindow::fillAlarmList()
     QFontMetrics fm(m_font);
     int fntHeight = fm.height() + FNT_ADD;
 
+    //TODO remove this
+//    m_timeFrame = 52;
+
     if (m_showCaption)
     {
        QString header;
@@ -80,9 +83,6 @@ void AlarmWindow::fillAlarmList()
     cookie_t *list, *iter;
     time_t now;
 
-    //TODO remove this
-//    m_timeFrame = 96;
-
     now = time(NULL);
     list = alarmd_event_query(now, now + m_timeFrame*3600, ALARM_EVENT_DISABLED, 0, NULL);
     if (list == NULL) {
@@ -101,6 +101,10 @@ void AlarmWindow::fillAlarmList()
                 alarm_event_t * aevent = alarmd_event_get (*iter);
 
                 int action_cnt = aevent->action_cnt;
+
+//                qDebug() << action_cnt;
+//                qDebug() << aevent->alarm_appid;
+
                 int recur = alarm_event_is_recurring (aevent);
                 if (((m_alarmFilter == 2) || ((m_alarmFilter == 1) && (action_cnt > 1)) || ((m_alarmFilter == 0) && (action_cnt == 2)))
                     && ((m_showRecurrent) || ((!m_showRecurrent) && (!recur))))
@@ -114,10 +118,10 @@ void AlarmWindow::fillAlarmList()
                         if (aevent->recurrence_cnt > 0)
                         {
                             toAdd = true;
-//                            alarm_recur_t* arecur = &aevent->recurrence_tab[0];
-  //                          const char* tz = alarm_event_get_alarm_tz(aevent);
-    //                        struct tm* rtm = localtime(&now);
-      //                      ttime = alarm_recur_next(arecur,rtm,tz);
+/*                            alarm_recur_t* arecur = &aevent->recurrence_tab[0];
+                            const char* tz = alarm_event_get_alarm_tz(aevent);
+                            struct tm* rtm = localtime(&now);
+                            ttime = alarm_recur_next(arecur,rtm,tz);*/
                             item->setIcon(icnRecur);
                         }
                     }
@@ -153,9 +157,18 @@ void AlarmWindow::fillAlarmList()
                             days = secs / (60 * 60 * 24);
                         }
 
-                        QString sTime;
+                        QString sTime ("");
 
-                        sTime = qtm.toString(Qt::DefaultLocaleShortDate);
+                        // show date of alarm - not used
+/*                        if (m_showDate) // show date before time
+                        {
+                            QDate qdt = qdtm.date();
+                            sTime += "[";
+                            sTime += qdt.toString(Qt::DefaultLocaleShortDate);
+                            sTime += "] ";
+                        }*/
+
+                        sTime += qtm.toString(Qt::DefaultLocaleShortDate);
                         if ((days > 0) || (m_showRemain))
                             sTime += " (";
                         if (days > 0) // calc for more than 1 day alarms
@@ -288,6 +301,8 @@ void AlarmWindow::loadSettings()
     m_alarmFilter = nalarmsettings::getInstance().alarmFilter();
     m_timeFrame = nalarmsettings::getInstance().timeFrame();
 
+    m_showDate = nalarmsettings::getInstance().isAlwaysShowDate();
+
     float aTr = float(100-nalarmsettings::getInstance().getTransparency());
     m_transparency = aTr/100;
 }
