@@ -205,3 +205,17 @@ void nalarmsettings::setTransparency(const int &aTrans) const
     QSettings sett(organizationName,applicationName);
     sett.setValue("Transparency",aTrans);
 }
+
+//get show date
+bool nalarmsettings::isAlwaysShowDate() const
+{
+    QSettings sett(organizationName,applicationName);
+    return sett.value("ShowDate",false).toBool();
+}
+
+//set show date
+void nalarmsettings::setAlwaysShowDate(const bool &aShow) const
+{
+    QSettings sett(organizationName,applicationName);
+    sett.setValue("ShowDate",aShow);
+}
