@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.0" language="fr">
+<TS version="2.0" language="fr_FR">
 <context>
     <name>AlarmWindow</name>
     <message>
@@ -14,12 +14,12 @@
         <translation>Alarmes dans les %1 heures</translation>
     </message>
     <message>
-        <location filename="alarmwindow.cpp" line="161"/>
+        <location filename="alarmwindow.cpp" line="162"/>
         <source>d</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="alarmwindow.cpp" line="219"/>
+        <location filename="alarmwindow.cpp" line="220"/>
         <source>--:--</source>
         <translation></translation>
     </message>
@@ -32,122 +32,137 @@
         <translation>Paramètres de &quot;Next Alarm&quot;</translation>
     </message>
     <message>
-        <location filename="settingsdialog.ui" line="38"/>
+        <location filename="settingsdialog.ui" line="35"/>
+        <source>Visual</source>
+        <translation>Effets visuel</translation>
+    </message>
+    <message>
+        <location filename="settingsdialog.ui" line="49"/>
         <source>Font</source>
         <translation>Fonte</translation>
     </message>
     <message>
-        <location filename="settingsdialog.ui" line="68"/>
+        <location filename="settingsdialog.ui" line="79"/>
         <source>B</source>
-        <translation>Gras</translation>
+        <translation>G</translation>
     </message>
     <message>
-        <location filename="settingsdialog.ui" line="86"/>
+        <location filename="settingsdialog.ui" line="97"/>
         <source>I</source>
-        <translation>Italique</translation>
+        <translation>I</translation>
     </message>
     <message>
-        <location filename="settingsdialog.ui" line="103"/>
+        <location filename="settingsdialog.ui" line="114"/>
         <source>Color</source>
         <translation>Couleur</translation>
     </message>
     <message>
-        <location filename="settingsdialog.ui" line="110"/>
+        <location filename="settingsdialog.ui" line="121"/>
         <source>12:48</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="settingsdialog.ui" line="132"/>
-        <source>Show</source>
-        <translation>Exposer</translation>
-    </message>
-    <message>
-        <location filename="settingsdialog.ui" line="149"/>
-        <source>Alarms only</source>
-        <translation>Seulement les alarmes</translation>
-    </message>
-    <message>
-        <location filename="settingsdialog.ui" line="154"/>
-        <source>Alarms + Calendar</source>
-        <translation>Alarmes + Calendrier</translation>
-    </message>
-    <message>
-        <location filename="settingsdialog.ui" line="159"/>
-        <source>All Events</source>
-        <translation>Toutes les alarmes</translation>
-    </message>
-    <message>
-        <location filename="settingsdialog.ui" line="167"/>
+        <location filename="settingsdialog.ui" line="140"/>
         <source>Lines</source>
         <translation>Lignes</translation>
     </message>
     <message>
-        <location filename="settingsdialog.ui" line="193"/>
+        <location filename="settingsdialog.ui" line="166"/>
         <source>Width</source>
         <translation>Largeur</translation>
     </message>
     <message>
-        <location filename="settingsdialog.ui" line="222"/>
+        <location filename="settingsdialog.ui" line="193"/>
+        <source>Transparency</source>
+        <translation>Transparence</translation>
+    </message>
+    <message>
+        <location filename="settingsdialog.ui" line="216"/>
+        <source>Alarms</source>
+        <translation>Alarmes</translation>
+    </message>
+    <message>
+        <location filename="settingsdialog.ui" line="227"/>
+        <source>Show</source>
+        <translation>Afficher</translation>
+    </message>
+    <message>
+        <location filename="settingsdialog.ui" line="244"/>
+        <source>Alarms only</source>
+        <translation>Seulement les alarmes</translation>
+    </message>
+    <message>
+        <location filename="settingsdialog.ui" line="249"/>
+        <source>Alarms + Calendar</source>
+        <translation>Alarmes + Calendrier</translation>
+    </message>
+    <message>
+        <location filename="settingsdialog.ui" line="254"/>
+        <source>All Events</source>
+        <translation>Toutes les alarmes</translation>
+    </message>
+    <message>
+        <location filename="settingsdialog.ui" line="268"/>
         <source>recurrent</source>
         <translation>Récurrent</translation>
     </message>
     <message>
-        <location filename="settingsdialog.ui" line="229"/>
+        <location filename="settingsdialog.ui" line="275"/>
         <source>Frame (h)</source>
         <translation>Durée (h)</translation>
     </message>
     <message>
-        <location filename="settingsdialog.ui" line="251"/>
-        <source>Time Remain</source>
+        <location filename="settingsdialog.ui" line="368"/>
+        <source>Show Time Remain</source>
         <translation>Temps restant</translation>
     </message>
     <message>
-        <location filename="settingsdialog.ui" line="270"/>
-        <source>Header</source>
+        <location filename="settingsdialog.ui" line="313"/>
+        <source>Show widget Header</source>
         <translation>Afficher l&apos;entête</translation>
     </message>
     <message>
-        <location filename="settingsdialog.ui" line="282"/>
-        <source>Title</source>
-        <translation>Titre</translation>
+        <location filename="settingsdialog.ui" line="338"/>
+        <source>Show alarm Title</source>s
+        <translation>Afficher le Titre</translation>
     </message>
     <message>
-        <location filename="settingsdialog.ui" line="294"/>
-        <source>Show empty</source>
-        <translation>Voir les vides</translation>
+        <location filename="settingsdialog.ui" line="337"/>
+        <source>Show when empty</source>
+        <translation>Voir quand c&apos;est vide</translation>
     </message>
     <message>
-        <location filename="settingsdialog.ui" line="307"/>
+        <location filename="settingsdialog.ui" line="352"/>
         <source>About</source>
         <translation>A propos de</translation>
     </message>
     <message>
-        <location filename="settingsdialog.ui" line="314"/>
+        <location filename="settingsdialog.ui" line="359"/>
         <source>About Qt</source>
         <translation>A propos de Qt</translation>
     </message>
     <message>
-        <location filename="settingsdialog.cpp" line="118"/>
+        <location filename="settingsdialog.cpp" line="122"/>
         <source>Next Alarm</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="settingsdialog.cpp" line="119"/>
+        <location filename="settingsdialog.cpp" line="123"/>
         <source>Developed with</source>
         <translation>Développé avec</translation>
     </message>
     <message>
-        <location filename="settingsdialog.cpp" line="120"/>
+        <location filename="settingsdialog.cpp" line="124"/>
         <source>Desktop widget, showing time of next alarms</source>
         <translation>Widget sur le bureau qui affiche les alarmes enregistrées</translation>
     </message>
     <message>
-        <location filename="settingsdialog.cpp" line="121"/>
+        <location filename="settingsdialog.cpp" line="125"/>
         <source>Send reports to:</source>
         <translation>Envoyé le rapport à:</translation>
     </message>
     <message>
-        <location filename="settingsdialog.cpp" line="128"/>
+        <location filename="settingsdialog.cpp" line="132"/>
         <source>About Next Alarm</source>
         <translation>A propos de &quot;Next Alarm&quot;</translation>
     </message>
